/*
	CheckIn.ms
	Version: 1.91
	Created On: November 23, 2002
	Created By: Jeff Hanna
	Modified On: March 12, 2003
	Modified By: Jeff Hanna
	tested using Max 4.26

	 Copyright 2003, Lodestone Games, LLC. All Rights Reserved.
	
	Checks a previously checked out Max scene back into the version control archive.
	
	
	v1.91 - Changed variable names to follow the programming guidelines.
	v1.9 - Changed name from "SaveToSourceControl" to "CheckIn". All "Source Control" and "SC" references changed to "Version Control 
	       and "VC".  Changed function call "ConvertArray" to "ConvertArrayDOS2Unix" to reflect the change made in LSUtilLib
	v1.8 - Copyright information added.
	v1.7 - Changed from reading strStartMapsFile and strMaxFileToEdit from FileProperties to using the persistent global variables, 
	       "pg_strMaxFilepath" and, "pg_strMapsFilePath". Moved, "bExit" and, "aNewPathnames" from global to local variables.	
	v1.6 - Changed the function call "ConvertArrays" to "ConvertArray" to reflect the change made in LSUtilLb.
	v1.5 - Fixed a bug that prevented the script from completing if the user answered "yes" to, the "Would you like to reopen..." dialog.
	v1.4 - Initial release.
*/

(
	--LOCAL VARIABLES
	-----------------
	local strCheckInVersion = "1.91" as string	-- Version number for display in the Max Listener window
	local bExit = false							-- Boolean to determine if the script should be exited.
	local bReOpen = false						-- Boolean to determine if the file should be re-opened.

	aAllMaps = #()
	aAllPathnames = #()
	aFilesToSubmit = #()
	aNewPathnames = #()
	aOriginalPathnames = #()
	aOtherMaps = #()
	aTempMapPathnames = #()

	
	--GLOBAL VARIABLES
	------------------

	
	--INCLUDED FILES
	----------------
	include "$scripts\\Lodestone\\LSUtilLib.ms"
	include "$scripts\\Lodestone\\VersionControl\\P4\\P4Lib.ms"
	

	--MAIN LOOP
	-----------
	print ("CheckIn, v" + strCheckInVersion + " loaded.")
	 
	-- This script is executed as a do-while loop so that it can be exited at any time 
	do
	(
		-- Build the aOriginalPathnames array to insure that it is intact.
		try
		(
			local FileIn = openFile pg_strMapsFilepath
			while not eof FileIn do
			(
				append aOriginalPathnames (readLine FileIn)
			)
			close FileIn
		)
		catch
		(
			messagebox "You do not have this file checked out from version control.\nThis scene can not be saved to version control." title:"Version Control"
			
			bExit = true
			exit
		)
		
		-- The user needs to enter a description of the changes and decide if they want to close the scene.
		createDialog rolloutGetDescription width:250 modal:true
		bReOpen = querybox "Would you like to reopen the scene and continue to work on it?" title:"Version Control"
		
		-- Save the file.
		max file save
		
		-- Get a list of all maps used in the scene
		aAllMaps = GetSceneMaps()
		aOtherMaps = GetOtherMaps()
		aAllMaps = aAllMaps + aOtherMaps
		
		-- Get the pathnames from that list. Then remove the duplicates
		aTempMapPathnames = GetBitmapsFromMaps aAllMaps
		RemoveDuplicates aTempMapPathnames
		
		-- Check all of the temporary new map pathnames against the original list. If it's not there, add it to the new map list.
		for i in aTempMapPathnames do
		(
			local iIndex = findItem aOriginalPathnames i
			if iIndex == 0 do
			(
				append aNewPathnames i
			)
		)
		
		-- The Max scene wouldn't be included in the Submit function if it's path and name weren't retrieved and added to the array.
		append aOriginalPathnames pg_strMaxFilepath
		
		VCAdd aNewPathnames

		-- Combine the arrays instead of executing all of the commands on each one seperately.
		aAllPathnames = aOriginalPathnames + aNewPathnames
				
		--Forcing a revert on all files will cause P4 to revert any file that is unchanged
		VCRevertUnchanged aAllPathnames

		-- 'Cause P4 Open and P4 Submit use Unix style relative pathing.
		aAllPathnames = ConvertArrayDOS2UNIX aAllPathnames

		-- Check the changelist after the revert and build an array, "aFilesToSubmit" from what's left.
		aFilesToSubmit = VCGetOpenedFiles aAllPathnames
		
		-- Check to see if the user wanted to reopen the file for editing after the save/submit.
		if bReOpen == false then
		(
			-- If not, then submit the files to source control.
			VCSubmit aFilesToSubmit

			-- Clean up any temporary files on the HD.
			deleteFile pg_strMapsFilePath
			deleteFile "$temp\\AddFiles.txt"
			deleteFile "$temp\\OpenedFiles.txt"
			deleteFile "$temp\\RevertFiles.txt"
			deleteFile "$temp\\SubmitFiles.txt"

			-- Resetting Max leaves global variables around. These commands undeclare them.
			pg_strMapsFilepath = undefined
			pg_strMaxFilepath = undefined
			
			--Reset Max to prevent further editting of the file.
			resetMaxFile #noPrompt
						
			bExit = true
			exit
		)
		else
		(
			-- If yes, then submit the files and immediately check them back out of the source control archive.
			VCSubmitAndReopen aFilesToSubmit
			
			-- Force a synchronization with the source control system, just to be on the save side.
			VCSyncAndCheckOut aAllPathnames pg_strMapsFilepath
			
			-- clean up any temporary files on the HD.
			deleteFile "$temp\\AddFiles.txt"
			deleteFile "$temp\\OpenedFiles.txt"
			deleteFile "$temp\\RevertFiles.txt"
			deleteFile "$temp\\SubmitFiles.txt"
			
			bExit = true
			exit
		)
	)
	while bExit == false
)