/*
	CheckOut.ms
	Version: 1.91
	Created On: November 23, 2002
	Created By: Jeff Hanna
	Modified On: March 12, 2003
	Modified By: Jeff Hanna
	tested using Max 4.26

	 Copyright 2003, Lodestone Games, LLC. All Rights Reserved.
	
	Synchronizes a Max scene and the bitmaps in it to the latest versions located in version control, then
	checks the file out of the source control archive and loads it into Max for editing.
	
		
	v1.91 - Changed the variable names to follow the programming guidelines.
	v1.9 - Changed name from "EditFromSourceControl" to "CheckOut". All "Source Control" and "SC" references changed to 
	       "Version Control and "VC".
	v1.8 - Added code to call the SCGetFileStats function from P4Lib.ms. This code prevents the max scene from being checked out twice.
	v1.7 - Copyright information added.
	v1.6 - Switched from storing strMaxFileToEdit and strStartMapsFile in the FileProperties page to storing them in the persistent 
	       global variables, "strMaxFilepath" and, "strMapsFilepath".
	v1.5 - Instead of showing an error requestor and quiting; now if the file is already opened for edit in source control when this 
	       script is run the file is opened via the regular max "open" command.v1.4 - Initial release.
*/

(
	--LOCAL VARIABLES
	-----------------
	local strCheckOutVersion = "1.9" as string	-- Version number for display in the Max Listener window
	local strFileToOpen = "" as string			-- Max file that will be opened.
	local strMaxFilepath = "" as string			-- Filepath of the temp text file that contains the max filename.
	local strMapsFilepath = "" as string		-- Filepath of the temp text file that contains the bitmap names
	
	aAllMaps = #()
	aMaxFile = #()
	aOtherMaps = #()	
	aStartMapPathnames = #()

	
	--GLOBAL VARIABLES
	------------------
	

	--INCLUDED FILES
	----------------
	include "$scripts\\Lodestone\\LSUtilLib.ms"
	include "$scripts\\Lodestone\\VersionControl\\P4\\P4Lib.ms"	
		
	
	--MAIN LOOP
	-----------
	-- print version information to the listener. Useful if a bug-report needs to be sent.
	print ("CheckOut, v" + strCheckOutVersion + " loaded.")
	
	-- Ask the user for the name of the max scene they'd like to open.
	strFileToOpen = getMaxOpenFileName types:"3ds max(*.max)|*.max|All|*.*|" 
	
		
	-- Check to make sure the scene isn't already open for edit in the source control app.
	if strFileToOpen != undefined then
	(
		-- If it's not already open it, add the file to the request that it become open for editing.
		append aMaxFile strFileToOpen
		
		-- Create two variables for path storage files. One for the max scene and one for all of the texturemaps in the scene.
		strMaxFilepath = ("$temp\\" + (getFilenameFile strFileToOpen) + "_MaxFile.txt") as string
		strMapsFilepath = ("$temp\\" + (getFilenameFile strFileToOpen) + "_StartMaps.txt") as string
		
		
		-- Attempt to open the map path storage file.
		local fileIn = openFile strMapsFilepath
		
		-- Check to see if any other users have this particular Max scene checked out from version control.
		bol_FileLocked = (VCGetFileStats strFileToOpen)
		
		
		-- If no one else has it checked out, check to see if this user has it checked out.
		if bol_FileLocked == false then
		(
			-- If the file doesn't exist, then the Max scene isn't isn't checked out from source control by this user.
			if fileIn == undefined then
			(
				-- Sync to the latest version and check the max scene out.
				VCSyncAndCheckOut aMaxFile strMaxFilepath
				
				-- Now load it into Max
				loadMaxFile strFileToOpen
							
				-- Traverse the node tree in the scene and gather all maps used.
				-- Find both maps assigned to materials and those that aren't.
				aAllMaps = GetSceneMaps()
				aOtherMaps = GetOtherMaps()
				aAllMaps = aAllMaps + aOtherMaps
				
				-- Get the bitmap names and file paths from the list of maps you just made.
				aStartMapPathnames = GetBitmapsFromMaps aAllMaps
				-- Remove any duplicate entries.
				RemoveDuplicates aStartMapPathnames
				
				-- Now sync to the latest version and check out those files files from source control
				VCSyncAndCheckOut aStartMapPathnames strMapsFilepath
				
				-- Force a refresh of all maps in the scene so that any that were updated by the sync become visible.
				freeSceneBitmaps()
				
				-- Commands to clean up the temporary disk file used in the synchronization process.
 				deleteFile strMaxFilePath
				
				-- Set these two persistent global variables so the other scripts can track whether this
				-- file has been added to source control, is open, etc...
				persistent global pg_strMaxFilepath = strFileToOpen
				persistent global pg_strMapsFilepath = strMapsFilepath
			)
			else
			(
				-- If the map path storage file exists, then this max scene is already checked out by this user. Just load it.
				close FileIn
				
				loadMaxFile strFileToOpen
				
				-- Refresh these two persistent global variables so the other scripts can track whether this
				-- file has been added to source control, is open, etc...
				persistent global pg_strMaxFilepath = strFileToOpen
				persistent global pg_strMapsFilepath = strMapsFilepath
			)
		)
	)
)