/*
	Revert.ms
	Version: 1.5
	Created On: December 05, 2002
	Created By: Jeff Hanna
	Modified On: March 12, 2003
	Modified By: Jeff Hanna
	tested using Max 4.26

	 Copyright 2003, Lodestone Games, LLC. All Rights Reserved.
	
	Discards all changes to the Max scene, resets Max, and synchronizes the user's machine with the most recently checked in version
	of the Max scene that is in the version control archive.
	
	
	v1.51 - Updated variable names to follow programming guidelines.
	v1.5 - Added confirmation dialog to the script.
	v1.4 - Changed name from "RevertScene" to "Revert". Changed function names to reflect overal package renaming from "Source Control" to "Version Control".
	v1.3 - Copyright Information added.
	v1.2 - Resetting the peristent global variables, "pg_strMaxFilepath" and, "pg_strMapsFilepath" at the end of the script.
	v1.1 - Initial release.
*/

(
	--LOCAL VARIABLES
	-----------------
	local strRevertVersion = "1.51" as string	-- Version number for display in the Max Listener window
	local bConfirm = false						-- Boolean to determine if the user really wants to revert.
		
	aOriginalPathnames = #()
		
	
	--GLOBAL VARIABLES
	------------------

	
	--INCLUDED FILES
	----------------
	include "$scripts\\Lodestone\\LSUtilLib.ms"
	include "$scripts\\Lodestone\\VersionControl\\P4\\P4Lib.ms"
	

	--MAIN LOOP
	-----------
	-- print version information to the listener. Useful if a bug-report needs to be sent.
	print ("RevertScene, v" + strRevertVersion + " loaded.")
	 
	if pg_strMapsFilepath == undefined then
	(
			-- If the variable doesn't exist then the scene has never been added to the version control archive.
			-- A file that isn't in the archive cannot be reverted.
			messagebox "This scene does not appear to be checked out from the version control archive.\nThis scene can not be reverted." title:"Version Control"
	)
	else
	(
		-- Build the OriginalPathnames array from the temp file on the HD
		bConfirm = querybox "This will discard all changes and revert your local depot to the last checked in version.\nDo you want to do this?"
		
		if bConfirm == true then
		(
			try
			(
				local FileIn = openFile pg_strMapsFilepath
				while not eof FileIn do
				(
					append aOriginalPathnames (readLine FileIn)
				)
				close FileIn
			)
			catch()
					
			-- Get the location of the max scene in the depot and add it to the array that will be passed to the revert function
			append aOriginalPathnames pg_strMaxFilepath
			
			--Forcing a revert on all files will cause P4 to revert any file that is unchanged
			VCRevertAll aOriginalPathnames
			
			-- Clean up the temporary disk file used in the synchronization process.
			deleteFile pg_strMapsFilepath
			deleteFile "$temp\\RevertFiles.txt"

			-- Resetting Max leaves global variables around. These commands undelcare them.
			pg_strMapsFilepath = undefined
			pg_strMaxFilepath = undefined
			
			-- Reset the max file to prevent any further editing of the file.
			resetMaxFile #noPrompt
		)
	)
)