/*
	UninstallPrevious.ms
	Version: 0.2
	Created On: February 18, 2003
	Created By: Jeff Hanna
	Modified On: March 12, 2003
	Modified By: Jeff Hanna
	Tested using Max 4.26
	
	 Copyright 2003 Lodestone Games, LLC. All Rights Reserved.

	
	Removes old SourceControlIO scripts, macroscripts, and menu entries. These files are being replaced by the new VersionControl script package.
	
	v0.2 - Changed variable names to follow programming guidelines.
	v0.1 - First version.
*/


(
	--LOCAL VARIABLES
	-----------------
	local iIndex = 0 as integer			
	local mainMenuBar = menuMan.getMainMenuBar()	
	local fileMenuItem = mainMenuBar.getItem 1	
	local helpMenuIndex = mainMenuBar.numItems()
	local helpMenuItem = mainMenuBar.getItem(helpMenuIndex)	
	local fileMenu = fileMenuItem.getSubMenu()	
	local helpMenu = helpMenuItem.getSubMenu()	
	local fileMenuCount = fileMenu.numItems()	
	local helpMenuCount = helpMenu.numItems()

	
	--MAIN LOOP
	-----------
	-- Delete the old script files from the max script directories.
	deleteFile "$max\\ui\\macroscripts\\Macro_EditFromSourceControl.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_RevertScene.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_SaveAsToSourceControl.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_SaveToSourceControl.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_SourceControl_IO_About.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_ViewFromSourceControl.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_AddNew.mcr"	
	deleteFile "$max\\ui\\macroscripts\\Macro_CheckIn.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_CheckOut.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_Revert.mcr"
	deleteFile "$max\\ui\\macroscripts\\Macro_View.mcr"
	deleteFile "$max\\scripts\\lodestone\\P4\\P4Lib.ms"
	deleteFile "$max\\scripts\\lodestone\\EditFromSourceControl.ms"
	deleteFile "$max\\scripts\\lodestone\\RevertScene.ms"
	deleteFile "$max\\scripts\\lodestone\\SaveAsToSourceControl.ms"
	deleteFile "$max\\scripts\\lodestone\\SaveToSourceControl.ms"
	deleteFile "$max\\scripts\\lodestone\\SourceControlIO_About.ms"
	deleteFile "$max\\scripts\\lodestone\\ViewFromSourceControl.ms"	
	deleteFile "$max\\stdplugs\\stdscripts\\SourceControlIO_Menus.ms"
	DOSCommand ("rmdir \"c:\\program files\\3dsmax42\\scripts\\lodestone\\p4\"")
	
	
	-- Traverse down the File menu until the old View command is found. Then delete that entry and the five above it.
	-- This removes all of the old menu entries.
	for i = 1 to 20 do
		(
			local menuItem = fileMenu.getItem i
			local strCompareString = menuItem.getTitle()
			
			if strCompareString == "View from Source Control" then
			(
				iIndex = i
				
				for j = 1 to 6 do
				(
					fileMenu.removeItemByPosition iIndex
				)
			)
			
		)
	
	
	-- Traverse the Help menu until the old About command is found. Then delete it.
	for i = 1 to helpMenuCount do
	(
		local menuItem = helpMenu.getItem i
		local strCompareString = menuItem.getTitle()
		
		if strCompareString == "About Source Control Integration Scripts" then
		(
			iIndex = (i - 1)
			
			for j = 1 to 2 do
			(
				helpMenu.removeItemByPosition iIndex
			)
		)
		
	)
	
	-- Refresh the menu bar so the changes are reflected in the UI.
	menuMan.updateMenuBar()
	
	-- Use the listener window to let the user know the script is finished.
	print "done"
)