/*
	VersionControl_Menus.ms
	Version: 1.41
	Created On: February 10, 2003
	Created By: Jeff Hanna
	Modified On: March 12, 2003
	Modified By: Jeff Hanna
	tested using Max 4.26

	 Copyright 2003 Lodestone Games, LLC. All Rights Reserved.
	
	Adds the proper Version Control File menu and Help menu commands to the user's Max script interface.
		
	
	v1.41 - Changed the variable names to follow the programming guidelines.
	v1.4 - Changed name from "SCIO_Menus" to "VersionControl_Menus". All "Source Control" and "SC" references changed to "Version Control and "VC"
	v1.3 - Copyright information added.
	v1.2 - Initial release.	
*/

(
	-- Variable to store the discovered menu entry index
	local iIndex = 0 as integer 
			
	--Check to see if this menu context has a stored class ID. If not, then create the ID and the menu entries
	if menuMan.registerMenuContext 0x387ab4e5 then
	(
		-- Remove the (now) unnecessary uninstaller file.
		deleteFile "$max\\scripts\\lodestone\\UninstallPrevious.ms"
	
		-- Get the main menu bar 
		local mainMenuBar = menuMan.getMainMenuBar()
		

		-- Find the File menu and the Help menu
		local fileMenuItem = mainMenuBar.getItem 1
		
		local helpMenuIndex = mainMenuBar.numItems()
		local helpMenuItem = mainMenuBar.getItem(helpMenuIndex)
		
		
		-- Get the File menu and the help menu from the fileMenuItem and helpMenuItem variables
		local fileMenu = fileMenuItem.getSubMenu()
		
		local helpMenu = helpMenuItem.getSubMenu()
		
		
		-- Get the number of entries in the File and Help menus
		local fileMenuCount = fileMenu.numItems()
		
		local helpMenuCount = helpMenu.numItems()
		
		
		-- Create a menu Seperatorarator item 
		local SeperatorItem = menuMan.createSeparatorItem()
		

		-- Create menu items that call the source control integration scripts and the about Script
		local RevertItem = menuMan.createActionItem "Revert" "Lodestone Tools"
		local AddNewItem = menuMan.createActionItem "AddNew" "Lodestone Tools"
		local CheckInItem = menuMan.createActionItem "CheckIn" "Lodestone Tools"
		local CheckOutItem = menuMan.createActionItem "CheckOut" "Lodestone Tools"
		local ViewItem = menuMan.createActionItem "View" "Lodestone Tools"
		local AboutItem = menuMan.createActionItem "VersionControl_About" "Lodestone Tools"
		
		
		-- Find the "Xref O$bjects..." menu entry so we can get the menu entry for it.
		for i = 1 to fileMenuCount do
		(
			-- convert each &File menu entry to a string for comparison
			local menuItem = fileMenu.getItem i
			local strCompareString = menuItem.getTitle()
			
			-- Once found, get its index #.
			if strCompareString == "XRef O&bjects..." then
			(
				iIndex = i								
			)
		)
				

		-- Add the new File menu entries at the proper menu index
		fileMenu.addItem SeperatorItem iIndex
		fileMenu.addItem ViewItem iIndex
		fileMenu.addItem RevertItem iIndex
		fileMenu.addItem AddNewItem iIndex
		fileMenu.addItem CheckInItem iIndex
		fileMenu.addItem CheckOutItem iIndex
		
		
		
		--  Add the new Help menu entry for the about box
		helpMenu.addItem SeperatorItem -1 		-- -1 is always the last item in the list.
		helpMenu.addItem AboutItem -1
		
		
		-- Redraw the menu bar with the new items
		menuMan.updateMenuBar()
	)
)