/*
	View.ms
	Version: 1.41
	Created On: November 23, 2002
	Created By: Jeff Hanna
	Modified On: March 12, 2003
	Modified By: Jeff Hanna
	tested using Max 4.26

	 Copyright 2003 Lodestone Games, LLC. All Rights Reserved.
	
	Synchronizes a max scene and the bitmaps in it to the latest versions located in version control,
	The file is then opened in Max without being checked out from the version control archive. This is useful for times when
	a user wants to look at the latest version of a file without making changes to it.
	
		
	v1.41 - Changed the variable names to follow the programming guidelines.
	v1.4 - Changed name from "ViewFromSourceControl" to "View". All "Source Control" and "SC" references changed to "Version Control and "VC"
	v1.3 - Copyright information added.
	v1.2 - Initial release.	
*/

(
	--LOCAL VARIABLES
	-----------------
	local strViewVersion = "1.41" as string		-- Version number for display in the Max Listener window
	local strFileToOpen = "" as string			-- The max file that should be loaded
	local strStartMapsFile = "" as string		-- The text file containing the bitmap names to be sync'd in P4.
	
	aAllMaps = #()
	aOtherMaps=#()
	aStartMapPathnames = #()
	

	--GLOBAL VARIABLES
	------------------
	
	
	--INCLUDED FILES
	----------------
	include "$scripts\\Lodestone\\LSUtilLib.ms"
	include "$scripts\\Lodestone\\VersionControl\\P4\\P4Lib.ms"
	
	
	--MAIN LOOP
	-----------
	-- print version information to the listener. Useful if a bug-report needs to be sent.
	print ("View, v" + strViewVersion + " loaded.")
	
	-- Ask the user for the name of the max scene they'd like to open.
	strFileToOpen = getMaxOpenFileName types:"3ds max(*.max)|*.max|All|*.*|" 
	
		
	-- Check to make sure the scene isn't already open for edit in the source control app.
	if strFileToOpen != undefined then
	(
		-- Add the name of the max scene to that array
		append aStartMapPathnames strFileToOpen
		
		-- Create a string containing the full DOS path of the file to be submitted to the source control system.
		strStartMapsFile = ("$temp\\" + (getFilenameFile strFileToOpen) + "_StartMaps.txt")
		
		-- Ask the source control system to sync all of the files listed in that file
		-- Yes, it's empty at the moment, but the SCSync function requires two variables as input.
		-- This syncs the Max scene.
		VCSync aStartMapPathnames strStartMapsFile
		
		-- load the max scene
		loadMaxFile strFileToOpen
		
		-- Traverse the node tree in the scene and gather all maps used.
		-- Find both maps assigned to materials and those that aren't.
		aAllMaps = GetSceneMaps()
		aOtherMaps = GetOtherMaps()
		aAllMaps = aAllMaps + aOtherMaps
			
		-- Get the bitmap names and file paths from the list of maps you just made.
		aStartMapPathnames = aStartMapPathnames + (GetBitmapsFromMaps aAllMaps)
		-- Remove any duplicate entries.
		RemoveDuplicates aStartMapPathnames
		
		-- Now sync to the latest version and check out those files files from source control
		VCSync aStartMapPathnames strStartMapsFile
		
		--Force a refresh of all maps in the scene so that any that were updated by the sync become visible.
		freeSceneBitmaps()
		
		-- Clean up the temporary disk file used in the synchronization process.
		deleteFile strStartMapsFile
	)
)